==> nim_core-1.0.0-rc.0.tar.gz: lib/src/event_subscribe/event_subscribe_service.dart <==
// Copyright (c) 2021 NetEase, Inc.  All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'dart:async';

import 'package:nim_core_platform_interface/nim_core_platform_interface.dart';

class EventSubscribeService {
  factory EventSubscribeService() {
    if (_singleton == null) {
      _singleton = EventSubscribeService._();
    }
    return _singleton!;
  }

  EventSubscribeService._();

  static EventSubscribeService? _singleton;

  EventSubscribeServicePlatform get _platform =>
      EventSubscribeServicePlatform.instance;

  Stream<List<Event>> get eventSubscribeStream =>
      EventSubscribeServicePlatform.instance.eventSubscribeStream.stream;

  ///订阅指定账号的在线状态事件
  Future<NIMResult<List<String>>> registerEventSubscribe(
      EventSubscribeRequest request) async {
    return _platform.registerEventSubscribe(request);
  }

  ///取消指定事件的全部订阅关系,只需填写事件类型
  Future<NIMResult<bool>> batchUnSubscribeEvent(
      EventSubscribeRequest request) async {
    return _platform.batchUnSubscribeEvent(request);
  }

  ///取消订阅指定账号的在线状态事件,只需填写事件类型和事件发布者账号集合
  Future<NIMResult<bool>> unregisterEventSubscribe(
      EventSubscribeRequest request) async {
    return _platform.unregisterEventSubscribe(request);
  }

  ///向订阅者发布事件
  Future<NIMResult<bool>> publishEvent(Event event) async {
    return _platform.publishEvent(event);
  }

  ///查询事件订阅，用于查询某种事件的订阅关系
  Future<NIMResult<List<EventSubscribeResult>>> querySubscribeEvent(
      EventSubscribeRequest request) async {
    return _platform.querySubscribeEvent(request);
  }
}

==> nim_core-1.0.5.tar.gz: lib/src/event_subscribe/event_subscribe_service.dart <==
// Copyright (c) 2022 NetEase, Inc. All rights reserved.
// Use of this source code is governed by a MIT license that can be
// found in the LICENSE file.

import 'dart:async';

import 'package:nim_core_platform_interface/nim_core_platform_interface.dart';

class EventSubscribeService {
  factory EventSubscribeService() {
    if (_singleton == null) {
      _singleton = EventSubscribeService._();
    }
    return _singleton!;
  }

  EventSubscribeService._();

  static EventSubscribeService? _singleton;

  EventSubscribeServicePlatform get _platform =>
      EventSubscribeServicePlatform.instance;

  Stream<List<Event>> get eventSubscribeStream =>
      EventSubscribeServicePlatform.instance.eventSubscribeStream.stream;

  ///订阅指定账号的在线状态事件
  Future<NIMResult<List<String>>> registerEventSubscribe(
      EventSubscribeRequest request) async {
    return _platform.registerEventSubscribe(request);
  }

  ///取消指定事件的全部订阅关系,只需填写事件类型
  Future<NIMResult<void>> batchUnSubscribeEvent(
      EventSubscribeRequest request) async {
    return _platform.batchUnSubscribeEvent(request);
  }

  ///取消订阅指定账号的在线状态事件,只需填写事件类型和事件发布者账号集合
  Future<NIMResult<void>> unregisterEventSubscribe(
      EventSubscribeRequest request) async {
    return _platform.unregisterEventSubscribe(request);
  }

  ///向订阅者发布事件
  Future<NIMResult<void>> publishEvent(Event event) async {
    return _platform.publishEvent(event);
  }

  ///查询事件订阅，用于查询某种事件的订阅关系
  Future<NIMResult<List<EventSubscribeResult>>> querySubscribeEvent(
      EventSubscribeRequest request) async {
    return _platform.querySubscribeEvent(request);
  }
}
